<?php

// Function to log errors
function logError($message) {
    file_put_contents("errors.log", date("[Y-m-d H:i:s]") . " ERROR: $message\n", FILE_APPEND);
}

// Function to check MX records
function checkMXRecords($domain) {
    $records = dns_get_record($domain, DNS_MX);
    
    if (!$records) {
        logError("No MX records found for $domain");
        return ["domain" => $domain, "error" => "No MX records found"];
    }
    
    // Extract MX hostnames
    $mxHosts = array_column($records, 'target');
    
    // Check if Office 365 is used
    $usesOffice365 = false;
    foreach ($mxHosts as $host) {
        if (strpos($host, "mail.protection.outlook.com") !== false) {
            $usesOffice365 = true;
            break;
        }
    }

    return ["domain" => $domain, "uses_office365" => $usesOffice365, "mx_records" => $mxHosts];
}

// Get domains from various sources
$domains = [];

// Read from a file (if `domains.txt` exists)
if (file_exists("domains.txt")) {
    $domains = file("domains.txt", FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
}

// Accept domains via URL query (?domains=example.com,test.com)
if (isset($_GET['domains'])) {
    $domains = array_merge($domains, explode(',', $_GET['domains']));
}

// Accept input from a POST request (form submission)
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['domains'])) {
    $inputDomains = explode("\n", trim($_POST['domains']));
    $domains = array_merge($domains, array_map('trim', $inputDomains));
}

// Remove duplicates and empty entries
$domains = array_unique(array_filter($domains));

// If no domains, show HTML form
if (empty($domains)) {
    ?>
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Office 365 MX Checker</title>
    </head>
    <body>
        <h2>Check if Domains Use Office 365</h2>
        <form action="w.php" method="post">
            <textarea name="domains" rows="5" cols="50" placeholder="Enter domains, one per line"></textarea><br>
            <input type="submit" value="Check Domains">
        </form>
    </body>
    </html>
    <?php
    exit;
}

// Process domains
$results = [];
foreach ($domains as $domain) {
    $results[] = checkMXRecords($domain);
}

// Output results as JSON
header('Content-Type: application/json');
echo json_encode($results, JSON_PRETTY_PRINT);

?>